@@ -19,10 +19,16 @@
  * USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <string.h>
 
 #include "common.h"
 
+const char *program_name = "basic";
+
 START_TEST (test_basic_status)
 {
 	pipeline *p;
@@ -101,6 +107,7 @@ START_TEST (test_basic_wait_all)
 	fail_unless (statuses[1] == 3 * 256);
 	fail_unless (statuses[2] == 0);
 	pipeline_free (p);
+	free (statuses);
 }
 END_TEST
 
@@ -200,6 +207,8 @@ START_TEST (test_basic_clearenv)
 		     "clearenv+setenv+dup returned second line '%s', expected 'bar\n'",
 		     line2);
 	pipeline_wait (p2);
+	pipeline_free (p2);
+	pipeline_free (p);
 }
 END_TEST
 
